@@ -10,6 +10,6 @@ def schedule(card):
 		return 0
 
 	# import the specific scheduler module
-	m = importlib.import_module('schedulers.' + card.scheduler)
+	m = importlib.import_module('.' + card.scheduler, package = 'vinca.schedulers')
 	# invoke the specific scheduler
 	return m.schedule(card)
